@@ -959,9 +959,9 @@ char *is[] = {       /* Icelandic */
 */
 
 char *se[] = {
-  "Nytt Brev",                      /* New Message        -HTML*/
+  "Nytt brev",                      /* New Message        -HTML*/
   "Svar" ,                          /* Reply              -HTML*/
-  "Angende den hr listan",      /* About this list    -HTML*/
+  "Om den hr listan",      /* About this list    -HTML*/
   "Slut p brevlistan",          /* End of Messages    -HTML*/
   "Start p brevlistan",         /* Start of Messages  -HTML*/
   "Datumvy",                        /* Date view          -HTML*/
@@ -972,10 +972,10 @@ char *se[] = {
   "Brev",                           /* Messages           -HTML*/
   "Startar",                        /* Starting           -HTML*/
   "Slutar",                         /* Ending             -HTML*/
-  "Angende det hr arkivet", /* About this archive -HTML*/
-  "sorterat p",                 /* Messages sorted by -HTML*/
+  "Om det hr arkivet", /* About this archive -HTML*/
+  "sortede efter",                 /* Messages sorted by -HTML*/
   "Andra brevarkiv",                /* Other mail archives-HTML*/
-  "P Datum",                    /* By Date            -HTML*/
+  "Datumsorterat",                    /* By Date            -HTML*/
   "Nyast brev",                     /* Most recent messages-HTML*/
   "frfattare",                  /* author             -HTML*/
   "datum",                          /* date               -HTML*/
@@ -987,7 +987,7 @@ char *se[] = {
   "Skriver trdindex till",      /* Writing thread index to -STDOUT*/
   "Skriver mnesindex till",     /* Writing subject index to-STDOUT*/
   "Skriver frfattarindex till", /* Writing author index to-STDOUT*/
-  "Senaste brev datum",             /* Last message date  -HTML*/
+  "Senaste brevdatum",             /* Last message date  -HTML*/
   "Arkiverat",                      /* Archived on        -HTML*/
   "Kan inte chmod",                 /* Can not chmod      -STDERR*/
   "Kunde inte skriva",              /* Could not write    -STDERR*/
@@ -997,17 +997,17 @@ char *se[] = {
   "Svar till",                      /* In reply to        -HTML*/
   "Nsta i trden",               /* Next in thread     -HTML*/
   "Kanske svar",                    /* Maybe reply        -HTML*/
-  "Per trd",                    /* By Thread          -HTML*/
-  "Per mne",                    /* By Subject         -HTML*/
-  "Per frfattare",              /* By Author          -HTML*/
+  "Trdsorterat",                    /* By Thread          -HTML*/
+  "mnessorterat",                    /* By Subject         -HTML*/
+  "Frfattarsorterat",              /* By Author          -HTML*/
   "Kan inte skapa directory",       /* Can not create directory -STDERR*/
-  "Skapar directory",               /* Creating directory -STDOUT*/
+  "Skapar katalog",               /* Creating directory -STDOUT*/
   "Konfigureringsvrden",        /* Configuration Values -STDOUT*/
   "path",                           /* path               -STDOUT*/
   "Fick slut p minne!",         /* Ran out of memory!-STDERR*/
   "Det hr arkivet skapades av", /* This archive was generated by-HTML*/
   "Delar",                          /* Elements           -STDOUT*/
-  "Inge delar",                     /* No Elements        -STDOUT*/
+  "Inga delar",                     /* No Elements        -STDOUT*/
   "Kan inte ppna brevarkivet",  /* Cannot open mail archive */
   "Lser ny header...",          /* Reading new header...-STDOUT*/
   "Laddar mailbox",                 /* Loading mailbox   -STDOUT   */
@@ -1020,7 +1020,7 @@ char *se[] = {
   "Kommando och kontrollvariabler", /* Command and Control Variables-STDOUT*/
   "Ja",                             /* Yes               -STDOUT*/
   "Nej",                            /* No                -STDOUT*/
-  "Angende arkivet: ej anvnd",      /* About the archive: not used-STDOUT */
+  "Om arkivet: ej anvnd",      /* About the archive: not used-STDOUT */
   "Andra arkiv: ej anvnd",      /* Other archives: not used-STDOUT*/
   "adress ej anvnd",            /* address not used  -STDOUT*/
   "Inbyggd <BODY> anvnd",       /* Builtin <BODY> statement used-STDOUT*/
@@ -1032,7 +1032,7 @@ char *se[] = {
   "Konfigurationsfil att lsa in",   /* Configuration file to read in -STDOUT*/
   "Directory att spara HTML-filerna i", 
                             /* The directory to save HTML files in -STDOUT*/
-  "Ls breven frn standard input", /* Read messages from standard input-STDOUT*/
+  "Ls breven frn standard in", /* Read messages from standard input-STDOUT*/
   "Namnet p utarkivet",         /* What to name the output archive-STDOUT*/
   "Brevarkiv att lsa in",       /* Mail archive to read in -STDOUT*/
   "Visa progress",                  /* Show progress      -STDOUT*/
@@ -1047,41 +1047,41 @@ char *se[] = {
   "Sprk ej supportat",          /* Language not supported  -STDERR*/
   "Ej angivet",                     /* Not set                 -STDOUT*/
   "Ej anvnt",                   /* Not used                -STDOUT*/
-  "Skapade bifogningsfil",          /* Created attachment file -STDOUT*/
-  "bifogning",                      /* attachment              -HTML*/
+  "Skapade bilagefil",          /* Created attachment file -STDOUT*/
+  "bilaga",                      /* attachment              -HTML*/
   "mode",                           /* mode                    -STDOUT*/
   "Lser gamla headers",         /* Reading old headers     -STDOUT*/
   "",                               /* for alignment only   -STDOUT*/
   "FEL",                            /* ERROR                   -STDERR*/
   "Adressen fr att posta till listan", 
                            /* The submission address of the list-STDERR*/
-  "Ls bara ett mail frn input",
+  "Ls bara ett brev frn in",
   "Frfattare",                  /* author             -HTML*/
   "Datum",                          /* date               -HTML*/
   "mne",                        /* subject            -HTML*/
-  "Mail actions",                   /* Mail actions (MA) header -HTML*/
-  "mail a new topic",               /* MA New Message      -HTML*/
-  "respond to this message",        /* MA Reply            -HTML*/
-  "Summary of Monthly Index Files", /* monthly             -HTML*/
-  "Summary of Yearly Index Files",  /* yearly              -HTML*/
-  "Build a GDBM header cache",   /* Build a GDBM header cache   -STDOUT*/
-  "Creating gdbm index... ",     /* Creating gdbm index         -STDOUT*/
-  "Can't create gdbm file... ",  /* Can't create gdbm index     -STDOUT*/
-  "Maintain an mbox archive",    /* Maintain an mbox archive    -STDOUT*/
-  "Can't both read from and write to an mbox.", /* "Can't both read from and write to an mbox." -STDOUT*/
-  "Attachment view",                      /* Attachment view  -HTML*/
-  "By messages with attachments",	  /* By messages with attachments -HTML*/
-  "Writing attachment index to",	  /* Writing attachment index to -STDOUT*/
-  "bytes",		    /* file size, so far only for attachments  -HTML */
-  "Cannot create symbolic link", /* MSG_CANNOT_CREATE_SYMLINK     -STDOUT */
-  "Cannot remove file", /* MSG_CANNOT_UNLINK                       -STDOUT */
-  "Previous Folder",  /* MSG_PREV_DIRECTORY                     -HTML */
-  "Next Folder",      /* MSG_NEXT_DIRECTORY                     -HTML */
-  "List of Folders",  /* MSG_FOLDERS_INDEX                      -HTML */
-  "This message has been deleted from the archive", /* MSG_DELETED -HTML */
-  "This message has expired",                       /* MSG_EXPIRED -HTML */
-  "(deleted message)", /* MSG_DEL_SHORT                            -HTML */
-  "Original text of this message", /* MSG_TXT_VERSION                          -HTML */
+  "E-postfunktioner",                   /* Mail actions (MA) header -HTML*/
+  "snd ett nytt mne",               /* MA New Message      -HTML*/
+  "svara p brevet",        /* MA Reply            -HTML*/
+  "Sammanfattning ver mnatliga indexfiler", /* monthly             -HTML*/
+  "Sammanfattning ver rliga indexfiler",  /* yearly              -HTML*/
+  "Bygger en GDBM-headercache",   /* Build a GDBM header cache   -STDOUT*/
+  "Skapar gdbm-index... ",     /* Creating gdbm index         -STDOUT*/
+  "Kan inte skapa gdbm-fil... ",  /* Can't create gdbm index     -STDOUT*/
+  "Underhll ett mbox-arkiv",    /* Maintain an mbox archive    -STDOUT*/
+  "Kan inte bde lsa frn och skriva till en mbox.", /* "Can't both read from and write to an mbox." -STDOUT*/
+  "Bilagevy",                      /* Attachment view  -HTML*/
+  "Efter brev med bilaga",	  /* By messages with attachments -HTML*/
+  "Skriver bilageindex till",	  /* Writing attachment index to -STDOUT*/
+  "byte",		    /* file size, so far only for attachments  -HTML */
+  "Kan inte skapa symbolisk lnk", /* MSG_CANNOT_CREATE_SYMLINK     -STDOUT */
+  "Kan inte ta bort fil", /* MSG_CANNOT_UNLINK                       -STDOUT */
+  "Fregende mapp",  /* MSG_PREV_DIRECTORY                     -HTML */
+  "Nsta mapp",      /* MSG_NEXT_DIRECTORY                     -HTML */
+  "Mapplista",  /* MSG_FOLDERS_INDEX                      -HTML */
+  "Detta brev har tagits bort frn arkivet", /* MSG_DELETED -HTML */
+  "Detta brev har utgtt",                       /* MSG_EXPIRED -HTML */
+  "(borttaget brev)", /* MSG_DEL_SHORT                            -HTML */
+  "Ursprunglig brevtext", /* MSG_TXT_VERSION                          -HTML */
   "This message has been filtered out",        /* MSG_FILTERED_OUT -HTML */
   NULL,                             /* End Of Message Table    - NOWHERE*/
 };
