@@ -246,7 +246,7 @@ char *tmpname(char *dir, char *pfx)
     char *f, *name;
     static int cntr = 0;
 
-    name = maprintf("%s/%s%dXXXXXX", dir, pfx, cntr++);
+    trio_asprintf(&name, "%s/%s%dXXXXXX", dir, pfx, cntr++);
     if (NULL == name)
 	return (NULL);
 
@@ -881,16 +881,19 @@ static char *mdecodeRFC2047(char *string, int length)
 ** Written by Daniel.Stenberg@haxx.nu
 */
 
-static void mdecodeQP(FILE *file, char *input, char **result, int *length)
+static char * mdecodeQP(FILE *file, char *input, char **result, int *length)
 {
     int outcount = 0;
     char *buffer = input;
     unsigned char inchar;
     char *output;
+    struct Push pbuf;
 
     int len = strlen(input);
     output = strsav(input);
 
+    INIT_PUSH(pbuf);
+
     while ((inchar = *input) != '\0') {
 
 	if (outcount >= len - 1) {
@@ -912,6 +915,7 @@ static void mdecodeQP(FILE *file, char *input, char **result, int *length)
 		if (!fgets(buffer, MAXLINE, file))
 		    break;
 		input = buffer;
+		PushString(&pbuf, buffer);
 		continue;
 	    }
 	    else if ('=' == *input) {
@@ -932,6 +936,7 @@ static void mdecodeQP(FILE *file, char *input, char **result, int *length)
 
     *result = output;
     *length = outcount;
+    RETURN_PUSH(pbuf);
 }
 
 char *createlink(char *format, char *dir, char *file, int num, char *type)
@@ -1010,8 +1015,8 @@ void emptydir(char *directory)
 		while ((entry = readdir(dir))) {
 		    if (!strcmp(".", entry->d_name) ||
 			!strcmp("..", entry->d_name)) continue;
-		    filename = maprintf("%s%c%s", realdir,
-					PATH_SEPARATOR, entry->d_name);
+		    trio_asprintf(&filename, "%s%c%s", realdir,
+				  PATH_SEPARATOR, entry->d_name);
 		    fprintf(stderr, "\nWe delete %s\n", filename);
 		    unlink(filename);
 		    free(filename);
@@ -1022,6 +1027,26 @@ void emptydir(char *directory)
     }
 }
 
+static void write_txt_file(struct emailinfo *emp, struct Push *raw_text_buf)
+{
+    char *txt_filename;
+    char *p = PUSH_STRING(*raw_text_buf);
+    char tmp_buf[32];
+    sprintf(tmp_buf, "%.4d", emp->msgnum);
+    txt_filename = htmlfilename(tmp_buf, emp, set_txtsuffix);
+    if ((!emp->is_deleted || (emp->is_deleted == 1 && set_delete_level > 2)
+	 || (emp->is_deleted == 2 && set_delete_level == 2))
+	&& (set_overwrite || !isfile(txt_filename))) {
+        FILE *fp = fopen(txt_filename, "w");
+	if (fp) {
+	    fwrite(p, strlen(p), 1, fp);
+	    fclose(fp);
+	}
+    }
+    free(p);
+    INIT_PUSH(*raw_text_buf);
+}
+
 /*
 ** Parsing...the heart of Hypermail!
 ** This loads in the articles from stdin or a mailbox, adding the right
@@ -1038,6 +1063,7 @@ int parsemail(char *mbox,	/* file name */
 	      int startnum)
 {
     FILE *fp, *fpo;
+    struct Push raw_text_buf;
     char *date = NULL;
     char *subject = NULL;
     char *msgid = NULL;
@@ -1052,6 +1078,10 @@ int parsemail(char *mbox,	/* file name */
     int num_added = 0;
     long exp_time = -1;
     int is_deleted = 0;
+    int pos;
+    bool *require_filter, *require_filter_full;
+    int require_filter_len, require_filter_full_len;
+    struct hmlist *tlist;
     char filename[MAXFILELEN];
     struct emailinfo *emp;
     char *att_dir = NULL;	/* directory name to store attachments in */
@@ -1135,21 +1165,23 @@ int parsemail(char *mbox,	/* file name */
 	if(set_append_filename && strncmp(set_append_filename, "$DIR/", 5)) {
 	    strcpy(filename, set_append_filename);
 	}
-	else if(snprintf(filename, sizeof(filename), "%s%s%s", dir,
-			 (dir[strlen(dir) - 1] == '/') ? "" : "/",
-			 set_append_filename ? set_append_filename + 5 : "mbox") 
+	else if(trio_snprintf(filename, sizeof(filename), "%s%s", dir,
+			      set_append_filename ? set_append_filename + 5
+			      : "mbox") 
 	   == sizeof(filename)) {
 	    progerr("Can't build mbox filename");
 	}
 	if(!(fpo = fopen(filename, "a"))) {
-	    snprintf(errmsg, sizeof(errmsg), "%s \"%s\".",
-		     lang[MSG_CANNOT_OPEN_MAIL_ARCHIVE], filename);
+	    trio_snprintf(errmsg, sizeof(errmsg), "%s \"%s\".",
+			  lang[MSG_CANNOT_OPEN_MAIL_ARCHIVE], filename);
 	    progerr(errmsg);
 	}
     }
 
     num = startnum;
 
+    INIT_PUSH(raw_text_buf);
+
     hassubject = 0;
     hasdate = 0;
     isinheader = 1;
@@ -1158,6 +1190,20 @@ int parsemail(char *mbox,	/* file name */
     bp = NULL;
     subject = NOSUBJECT;
 
+    require_filter_len = require_filter_full_len = 0;
+    for (tlist = set_filter_require; tlist != NULL; require_filter_len++, tlist = tlist->next)
+	;
+    for (tlist = set_filter_require_full_body; tlist != NULL;
+	 require_filter_full_len++, tlist = tlist->next)
+	;
+    pos = require_filter_len + require_filter_full_len;
+    require_filter = (bool *)emalloc(pos * sizeof(*require_filter));
+    require_filter_full = require_filter + require_filter_len;
+    for (pos = 0; pos < require_filter_len; ++pos)
+	require_filter[pos] = FALSE;
+    for (pos = 0; pos < require_filter_full_len; ++pos)
+	require_filter_full[pos] = FALSE;
+
     if (!increment) {
 	replylist = NULL;
 	subjectlist = NULL;
@@ -1177,7 +1223,8 @@ int parsemail(char *mbox,	/* file name */
 	}
     }
 
-    while (fgets(line_buf, MAXLINE, fp) != NULL) {
+    for ( ; fgets(line_buf, MAXLINE, fp) != NULL; 
+	  set_txtsuffix ? PushString(&raw_text_buf, line_buf) : 0) {
 #if DEBUG_PARSE
 	printf("IN: %s", line);
 #endif 
@@ -1187,6 +1234,14 @@ int parsemail(char *mbox,	/* file name */
 	    }
 	}
 	line = line_buf + set_ietf_mbox; 
+	if (!is_deleted &&
+	    inlist_regex_pos(set_filter_out_full_body, line) != -1) {
+	    is_deleted = 4;
+	}
+	pos = inlist_regex_pos(set_filter_require_full_body, line);
+	if (pos != -1 && pos < require_filter_full_len) {
+	    require_filter_full[pos] = TRUE;
+	}
 	if (isinheader) {
 	    if (!strncasecmp(line_buf, "From ", 5))
 		strcpymax(fromdate, dp = getfromdate(line), DATESTRLEN);
@@ -1262,6 +1317,16 @@ int parsemail(char *mbox,	/* file name */
 			free(val);
 		    }
 
+		    if (!is_deleted &&
+			inlist_regex_pos(set_filter_out, head->line) != -1) {
+		        is_deleted = 4;
+		    }
+
+		    pos = inlist_regex_pos(set_filter_require, head->line);
+		    if (pos != -1 && pos < require_filter_len) {
+		        require_filter[pos] = TRUE;
+		    }
+
 		    if (!strncasecmp(head->line, "Date:", 5)) {
 			date = getmaildate(head->line);
 			head->parsedheader = TRUE;
@@ -1669,13 +1734,30 @@ int parsemail(char *mbox,	/* file name */
 			    decode = ENCODE_NORMAL;
 			}
 			else if (!strncasecmp(ptr, "x-uue", 5)) {
+			    struct Push pbuf;
+			    char *p2;
+			    INIT_PUSH(pbuf);
 			    decode = ENCODE_UUENCODE;
 
-			    if (uudecode(fp, line, line, NULL, TRUE))
+			    if (uudecode(fp, line, line, NULL, &pbuf))
 				/*
 				 * oh gee, we failed this is chaos 
                                  */
 				break;
+			    p2 = PUSH_STRING(pbuf);
+			    if (p2) {
+			        if (set_append) {
+				    if(fputs(p2, fpo) < 0) {
+				        progerr("Can't write to \"mbox\"");
+				    }
+				}
+				if (set_txtsuffix) {
+				    PushString(&raw_text_buf, line_buf);
+				    line_buf[0] = 0; /*avoid dup at next for iter*/
+				    PushString(&raw_text_buf, p2);
+				}
+				free(p2);
+			    }
 			}
 			else {
 			    /* Unknown format, we use default decoding */
@@ -1773,10 +1855,17 @@ int parsemail(char *mbox,	/* file name */
 		if (emp) {
 		    emp->exp_time = exp_time;
 		    emp->is_deleted = is_deleted;
-		    if (insert_in_lists(emp))
+		    if (insert_in_lists(emp, require_filter,
+					require_filter_len + require_filter_full_len))
 		        ++num_added;
 		    num++;
 		}
+		for (pos = 0; pos < require_filter_len; ++pos)
+		    require_filter[pos] = FALSE;
+		for (pos = 0; pos < require_filter_full_len; ++pos)
+		    require_filter_full[pos] = FALSE;
+		if (set_txtsuffix)
+		    write_txt_file(emp, &raw_text_buf);
 
 		if (hasdate)
 		    free(date);
@@ -1960,14 +2049,24 @@ int parsemail(char *mbox,	/* file name */
 
 		switch (decode) {
 		case ENCODE_QP:
-		    mdecodeQP(fp, line, &data, &datalen);
+		    {
+			char *p2 = mdecodeQP(fp, line, &data, &datalen);
+			if (p2) {
+			    if (set_txtsuffix) {
+			        PushString(&raw_text_buf, line_buf);
+				line_buf[0] = 0;
+				PushString(&raw_text_buf, p2);
+			    }
+			    free(p2);
+			}
+		    }
 		    break;
 		case ENCODE_BASE64:
 		    base64Decode(line, newbuffer, &datalen);
 		    data = newbuffer;
 		    break;
 		case ENCODE_UUENCODE:
-		    uudecode(NULL, line, newbuffer, &datalen, FALSE);
+		    uudecode(NULL, line, newbuffer, &datalen, NULL);
 		    data = newbuffer;
 		    break;
 		case ENCODE_NORMAL:
@@ -2061,8 +2160,8 @@ int parsemail(char *mbox,	/* file name */
 			    if (att_dir == NULL) {
 
 				/* first check the DIR_PREFIXER */
-				att_dir = maprintf("%s%c" DIR_PREFIXER "%04d",
-					     dir, PATH_SEPARATOR, num);
+				trio_asprintf(&att_dir,"%s%c" DIR_PREFIXER "%04d",
+					      dir, PATH_SEPARATOR, num);
 				check1dir(att_dir);
 				/* If this is a repeated run on the same archive we already
 				 * have HTML'ized, we risk extracting the same attachments
@@ -2077,8 +2176,8 @@ int parsemail(char *mbox,	/* file name */
 				if (set_usemeta) {
 				    /* make the meta dir where we'll store the meta info,
 				       such as content-type */
-				    meta_dir = maprintf("%s%c" META_DIR, att_dir,
-						 PATH_SEPARATOR);
+				    trio_asprintf(&meta_dir, "%s%c" META_DIR,
+						  att_dir, PATH_SEPARATOR);
 				    check1dir(meta_dir);
 				}
 			    }
@@ -2098,9 +2197,9 @@ int parsemail(char *mbox,	/* file name */
 				else
 				    fname = FILE_SUFFIXER;
 
-				binname = maprintf("%s%c%02d-%s",
-						   att_dir, PATH_SEPARATOR,
-						   att_counter, fname);
+				trio_asprintf(&binname, "%s%c%02d-%s",
+					      att_dir, PATH_SEPARATOR,
+					      att_counter, fname);
 				/* @@ move this one up */
 				/* att_counter++; */
 			    }
@@ -2111,8 +2210,13 @@ int parsemail(char *mbox,	/* file name */
                              * directories must exist first...  
                              */
 
+#ifdef O_BINARY
+#define OPENBITMASK O_WRONLY | O_CREAT | O_BINARY
+#else
+#define OPENBITMASK O_WRONLY | O_CREAT
+#endif
 			    if (binname) {
-				binfile = open(binname, O_WRONLY | O_CREAT,
+				binfile = open(binname, OPENBITMASK,
 					       set_filemode);
 
 				if (-1 != binfile) {
@@ -2129,12 +2233,11 @@ int parsemail(char *mbox,	/* file name */
 
 					ptr = strrchr(binname, PATH_SEPARATOR);
 					*ptr = '\0';
-					meta_file =
-					    maprintf("%s%c%s"
-						     META_EXTENSION,
-						     meta_dir,
-						     PATH_SEPARATOR,
-						     ptr + 1);
+					trio_asprintf(&meta_file, "%s%c%s"
+						      META_EXTENSION,
+						      meta_dir,
+						      PATH_SEPARATOR,
+						      ptr + 1);
 					*ptr = PATH_SEPARATOR;
 					file_ptr = fopen(meta_file, "w");
 					if (file_ptr) {
@@ -2173,6 +2276,7 @@ int parsemail(char *mbox,	/* file name */
 				if (strlen(file) <= 500) {
 				    char *desc;
 				    char *sp;
+				    struct emailsubdir *subdir;
 
 				    if (description && description[0] != '\0'
                                         && hasblack(description))
@@ -2189,15 +2293,24 @@ int parsemail(char *mbox,	/* file name */
 				    if (description)
 					description = NULL;
 
+				    subdir = NULL;
+				    if (set_msgsperfolder || set_folder_by_date) {
+					struct emailinfo e;
+					fill_email_dates(&e, date, fromdate,
+							 NULL, NULL);
+					subdir = msg_subdir(num, e.date);
+				    }
+
 				    if (inline_force ||
 					inlinecontent(type)) {
 					/* if we know our browsers can show this type of context
 					   as-is, we make a <img> tag instead of <a href>! */
 
-					snprintf(buffer, sizeof(buffer),
-						 "%s<img src=\"%s%c%s\" alt=\"%s\">\n",
+					trio_snprintf(buffer, sizeof(buffer),
+						 "%s<img src=\"%s%s%c%s\" alt=\"%s\">\n",
 						 (set_showhr ? "<hr noshade>\n" :
 						  ""),
+						 subdir ? subdir->rel_path_to_top : "",
 						 &att_dir[strlen(dir) + 1],
 						 PATH_SEPARATOR, file,
 						 desc);
@@ -2209,17 +2322,10 @@ int parsemail(char *mbox,	/* file name */
 								+ 1],
 						       file, num, type);
 
-					struct emailsubdir *subdir = NULL;
-					if (set_msgsperfolder || set_folder_by_date) {
-					    struct emailinfo e;
-					    fill_email_dates(&e, date, fromdate,
-							     NULL, NULL);
-					    subdir = msg_subdir(num, e.date);
-					}
 					if ((sp = strchr(desc, '\n')) !=
 					    NULL) *sp = '\0';
 
-					snprintf(buffer, sizeof(buffer),
+					trio_snprintf(buffer, sizeof(buffer),
 						 "%s<ul>\n<li>%s %s: <a href=\"%s%s\">%s</a>\n</ul>\n",
 						 (set_showhr ? "<hr noshade>\n" :
 						  ""), type,
@@ -2234,7 +2340,7 @@ int parsemail(char *mbox,	/* file name */
 				    bp =
 					addbody(bp, &lp, buffer,
 						BODY_HTMLIZED | bodyflags);
-				    snprintf(buffer, sizeof(buffer),
+				    trio_snprintf(buffer, sizeof(buffer),
 					     "<!-- attachment=\"%.80s\" -->\n",
 					     file);
 				    bp =
@@ -2273,7 +2379,6 @@ int parsemail(char *mbox,	/* file name */
 	progerr("Can't close \"mbox\"");
     }
 
-
     if (!isinheader || readone) {
 	if (!hassubject)
 	    subject = NOSUBJECT;
@@ -2292,8 +2397,11 @@ int parsemail(char *mbox,	/* file name */
 	if (emp) {
 	    emp->exp_time = exp_time;
 	    emp->is_deleted = is_deleted;
-	    if (insert_in_lists(emp))
+	    if (insert_in_lists(emp, require_filter,
+				require_filter_len + require_filter_full_len))
 	        ++num_added;
+	    if (set_txtsuffix)
+	        write_txt_file(emp, &raw_text_buf);
 	    num++;
 	}
 
@@ -2350,6 +2458,7 @@ int parsemail(char *mbox,	/* file name */
 	hassubject = 0;
 	hasdate = 0;
     }
+    free(require_filter);
 
     if (set_showprogress && !readone)
 	print_progress(num, lang[MSG_ARTICLES], NULL);
@@ -2437,9 +2546,7 @@ int parse_old_html(int num, struct emailinfo *ep, int parse_body,
     struct body *lp = NULL;
 
     struct emailsubdir *subdir = ep ? ep->subdir : msg_subdir(num, 0);
-    char *filename = maprintf("%s%s%.4d.%s", set_dir,
-			      subdir ? subdir->subdir : "",
-			      num, set_htmlsuffix);
+    char *filename;
 
     FILE *fp;
 
@@ -2449,6 +2556,8 @@ int parse_old_html(int num, struct emailinfo *ep, int parse_body,
 	sprintf(inreply_start, "<strong>%s:</strong> <a href=\"",
 		lang[MSG_IN_REPLY_TO]);
     }
+    trio_asprintf(&filename, "%s%s%.4d.%s", set_dir,
+		  subdir ? subdir->subdir : "", num, set_htmlsuffix);
 
     /*
      * fromdate == <!-- received="Wed Jun  3 10:12:00 1998 CDT" -->
@@ -2586,7 +2695,7 @@ int parse_old_html(int num, struct emailinfo *ep, int parse_body,
 	    if (do_insert) {
 	        emp->exp_time = exp_time;
 		emp->is_deleted = is_deleted;
-		if (insert_in_lists(emp))
+		if (insert_in_lists(emp, NULL, 0))
 		    ++num_added;
 	    }
 
@@ -2667,17 +2776,17 @@ static int loadoldheadersfrommessages(char *dir, int num_from_gdbm)
 	first_read_body = max_num - set_searchbackmsgnum;
 	if (first_read_body < 0)
 	    first_read_body = 0;
-	num = first_read_body;
+	if (num_from_gdbm != -1)
+	    num = first_read_body;
     }
 #if 0
     else if (set_searchbackmsgnum && set_increment) {
 	int jump = 1000;	 /* search for biggest message number */
 	while (jump && first_read_body >= 0) {
 	    subdir = msg_subdir(first_read_body, 0);
-	    filename = maprintf("%s%s%s%.4d.%s", set_dir,
-				(dir[strlen(dir) - 1] == '/') ? "" : "/",
-				subdir ? subdir->subdir : "",
-				first_read_body, set_htmlsuffix);
+	    trio_asprintf(&filename,"%s%s%.4d.%s", set_dir,
+			  subdir ? subdir->subdir : "",
+			  first_read_body, set_htmlsuffix);
 	    if ((fp = fopen(filename, "r")) != NULL) {
 	        fclose(fp);
 		if (jump < 0) jump = -jump/2;
@@ -2698,12 +2807,25 @@ static int loadoldheadersfrommessages(char *dir, int num_from_gdbm)
 	    return 0;
 	if (!hashnumlookup(first_read_body, &e0)) {
 #ifdef GDBM
-	    if (set_usegdbm)
-	        sprintf(errmsg,
-			"set_folder_by_date error old msg %d num_from_gdbm %d",
-			first_read_body, num_from_gdbm);
+	    if (set_usegdbm) {
+	        if (num_from_gdbm == -1) {
+		    if (is_empty_archive())
+		        return 0;
+		    sprintf(errmsg,
+			    "Error: This archive does not appear to be empty, "
+			    "and it has no gdbm file\n(%s). If you want to "
+			    "use incremental updates with the folder_by_date\n"
+			    "option, you must start with an empty archive or "
+			    "with an archive\nthat was generated using the "
+			    "usegdbm option.", GDBM_INDEX_NAME);
+		}
+		else
+		    sprintf(errmsg,
+			    "Error set_folder_by_date msg %d num_from_gdbm %d",
+			    first_read_body, num_from_gdbm);
+	    }
 	    else
-	        sprintf(errmsg, "folder_by_date requires usegdbm option");
+	        sprintf(errmsg, "folder_by_date with incremental update requires usegdbm option");
 #else
 	        sprintf(errmsg, "folder_by_date requires usegdbm option"
 			". gdbm support has not been compiled into this"
@@ -2787,8 +2909,8 @@ static int loadoldheadersfromGDBMindex(char *dir)
        *   isodate      v2.0
        */
 
-      indexname = maprintf((dir[strlen(dir)-1] == '/') ? "%s%s" : "%s/%s",
-			   dir, GDBM_INDEX_NAME);
+      trio_asprintf(&indexname, (dir[strlen(dir)-1] == '/') ? "%s%s" : "%s/%s",
+		    dir, GDBM_INDEX_NAME);
 
       if(gp = gdbm_open(indexname, 0, GDBM_READER, 0, 0)) {
 
@@ -2864,12 +2986,12 @@ static int loadoldheadersfromGDBMindex(char *dir)
 			   fromdate, charset, isodate, isofromdate, bp)) {
 	      emp->exp_time = exp_time;
 	      emp->is_deleted = is_deleted;
-	      if (insert_in_lists(emp))
+	      if (insert_in_lists(emp, NULL, 0))
 		  ++num_added;
 	      if (num == max_num) {
 		  char *filename = articlehtmlfilename(emp);
 		  if (!isfile(filename)) {
-		      snprintf(errmsg, sizeof(errmsg),
+		      trio_snprintf(errmsg, sizeof(errmsg),
 			       "%s \"%s\". If you deleted files,"
 			       " you need to delete the gdbm file %s as well.",
 			       lang[MSG_CANNOT_OPEN_MAIL_ARCHIVE],
