@@ -1,5 +1,5 @@
 /*
-** $Id: setup.c,v 1.19 2001/05/12 01:45:21 pcm Exp $
+** $Id: setup.c,v 1.21 2001/06/26 23:59:23 pcm Exp $
 */
 
 #include "hypermail.h"
@@ -685,7 +685,10 @@ void PreConfig(void)
 	case CFG_SWITCH:
 	case CFG_INTEGER:
 	case CFG_OCTAL:
-	    *(int *)cfg[i].value = (int)defval;
+	    if (defval == cfg[i].def)
+	        *(int *)cfg[i].value = (int)defval;
+	    else
+	        *(int *)cfg[i].value = atoi(defval);
 	    break;
 	case CFG_LIST:
 	    if (defval) {
