@@ -80,7 +80,7 @@ char *PushString(struct Push *push, const char *append)
 {				/* string to append */
     char *string = NULL;
 
-#if 0
+#if 1
     return PushNString(push, append, strlen(append));
 #else
     while (*append) {		/* continue until zero termination */
@@ -248,7 +248,8 @@ char *strcasestr (char *phaystack, const char *pneedle)
 	      a = *++haystack;
 	      if (a == '\0')
 		goto ret0;
-shloop:	    }
+shloop:	    ;
+    	 }
           while (tolower (a) != b);
 
 jin:	  a = *++haystack;
@@ -740,7 +741,8 @@ char *makemailcommand(char *mailcommand, char *email, char *id, char *subject)
 
     /* remade to deal with any-length strings */
     /* tmpsubject = maprintf("%s%s", (hasre) ? "" : "Re: ", (convsubj) ? convsubj : ""); */
-    tmpsubject = maprintf("%s%s", (convsubj && !hasre) ? "Re: " : "", (convsubj) ? convsubj : "");
+    trio_asprintf(&tmpsubject, "%s%s", (convsubj && !hasre)
+		  ? "Re: " : "", (convsubj) ? convsubj : "");
 
 
 	if ((cp = strrchr(email, ' ')) != NULL)
@@ -849,16 +851,16 @@ char *parseemail(char *input,	/* string to parse */
 			PushNString(&buff, lastpos, email - lastpos);
 		    }
 
-                    msnprintf(mailaddr, sizeof(mailaddr),"%.*s%s%s", 
-                            ptr-email, email, at, mailbuff);
+                    trio_snprintf(mailaddr, sizeof(mailaddr),"%.*s%s%s", 
+				  ptr-email, email, at, mailbuff);
 
 		    if (valid_root_domain(mailaddr)) {
 			char *mailcmd = makemailcommand(set_mailcommand,
 							mailaddr, mid,
 							msubject);
-			msnprintf(tempbuff, sizeof(tempbuff),
-				  "<a href=\"%s\">%.*s%s%s</a>", mailcmd,
-				  ptr - email, email, at, mailbuff);
+			trio_snprintf(tempbuff, sizeof(tempbuff),
+				      "<a href=\"%s\">%.*s%s%s</a>", mailcmd,
+				      ptr - email, email, at, mailbuff);
 
 			free(mailcmd);
 
@@ -1040,9 +1042,9 @@ char *parseurl(char *input)
 		}
 	    }
 	    if(accepted) {
-	        msnprintf(tempbuff, sizeof(tempbuff),
-			  "<a href=\"%s%s\">%s%s</a>",
-			  thisprotocol, urlbuff, thisprotocol, urlbuff);
+	        trio_snprintf(tempbuff, sizeof(tempbuff),
+			      "<a href=\"%s%s\">%s%s</a>",
+			      thisprotocol, urlbuff, thisprotocol, urlbuff);
 		PushString(&buff, tempbuff); /* append the tag buffer */
 		inputp += strlen(urlbuff);
 	    } else {
